.. _entity:

========
Entities
========

An Entity models an individual thing. Each Entity has a unique identity in that you can distinguish its individuality from among all other Entities of the same or a different type.

Entities can change continuously over a long period of time. Even when changes are so extensive that the object might seem much different from what it began as, it is the same object by identity.
